
import dbus
import e_dbus
import time

class SMSSender(object):

    def __init__(self, logger=None):
        self.logger = logger
        self.dbus = dbus.SystemBus(mainloop=e_dbus.DBusEcoreMainLoop())
        self.gsm_device_obj = self.dbus.get_object(
                'org.freesmartphone.ogsmd', 
                '/org/freesmartphone/GSM/Device')
        self.gsm_device_iface = dbus.Interface(self.gsm_device_obj, 
                                               'org.freesmartphone.GSM.Device')
        self.gsm_network_iface = dbus.Interface(self.gsm_device_obj, 
                                                'org.freesmartphone.GSM.Network')
        self.gsm_sim_iface = dbus.Interface(self.gsm_device_obj, 
                                            'org.freesmartphone.GSM.SIM')

    def log(self, message):
        if self.logger is not None:
            self.logger(message)

    def send(self, number, text):
        self.activate_gsm()
        self.log("Storing message to SIM")
        self.gsm_sim_iface.StoreMessage(
            number, text,
            reply_handler=self.onStored,
            error_handler=self.onStoreError,
        )

    def activate_gsm(self):
        gsm_status = self.gsm_network_iface.GetStatus()
        if gsm_status["registration"] == 'unregistered':
            try:
                self.gsm_device_iface.SetAntennaPower(True)
                self.gsm_network_iface.Register()
            except dbus.DBusException:
                self.log('Registration failed, retrying')
                return False

        self.log('GSM active')
        return True

    def onStored(self, result):
        self.log("Sending...")
        self.gsm_sim_iface.SendStoredMessage(
            result,
            reply_handler=self.onMessageSent,
            error_handler=self.onSendError
        )

    def onStoreError(self, e):
        self.log("SIM store error: %s" % str(e))

    def onMessageSent(self):
        self.log("Message sent")

    def onSendError(self, e):
        self.log("Send error: %s" % str(e))

