#!/usr/bin/python 

import ecore
import ecore.evas
import edje
import random
import accel
from SMSSender import SMSSender
from quotes import QUOTES

THROW_WAIT_SECS = 3
TRIGGER_Z = 700
TRIGGER_X = 800 

MIN_NUMBER_LEN = 11

class ThrowApp(object):

    def __init__(self):
        self.text = []
        self.sender = SMSSender(self.set_status)

        self.ee = ecore.evas.SoftwareX11(w=480, h=640)
        self.ee.title = 'throw'
        self.ee.callback_resize = self.on_resize
        canvas = self.ee.evas

        self.edje_obj = edje.Edje(canvas, 
                                  file='/home/root/throw.edj', 
                                  group='main')
        self.edje_obj.size = canvas.size
        self.edje_obj.show()

        self.edje_obj.signal_callback_add("mouse,clicked,1", "button_*", 
                                     self.on_dialer_button_pressed)

        self.edje_obj.focus = True
        self.ee.show()

        self._throw_acc = 0
        ecore.timer_add(0.5, self.activate_loop)
        ecore.timer_add(3.0, self.throw_detect)

    def on_resize(self, evas_obj):
        x, y, w, h = evas_obj.evas.viewport
        self.edje_obj.size = (w, h)
        
    def activate_loop(self):
        self.set_status('Activating GSM...')
        if not self.sender.activate_gsm():
            ecore.timer_add(0.5, self.activate_loop)

    def throw_detect(self):
        READY_MSG = 'Ready...'
        if len(self.text) >= MIN_NUMBER_LEN:
            self.set_status(READY_MSG)
            t, (x, y, z) = accel.sample()
            if z > TRIGGER_Z and abs(x) > TRIGGER_X:
                self._throw_acc += 1
                if self._throw_acc >= 2:
                    self.set_status('Throw detected')
                    self.send_quote()
                    self._throw_acc = 0
            ecore.timer_add(0.03, self.throw_detect)
        else:
            if self.get_status() == READY_MSG:
                self.set_status('')
            self._throw_acc = 0
            ecore.timer_add(0.4, self.throw_detect)

    def send_quote(self):
        self.sender.send(''.join(self.text), random.choice(QUOTES))
        self.text[:] = []
        self.update_number()

    def on_dialer_button_pressed(self, edje_obj, emission, source):
        key = source.split('_', 1)[1]
        if key == 'delete':
            if self.text:
                self.text.pop()
        elif key == 'plus':
            self.text.append('+')
        elif key == 'hash':
            self.text.append('#')
        else:
            self.text.append(key)
        self.update_number()

    def update_number(self):
        to_render = u''.join(self.text) + u'  '
        self.edje_obj.part_text_set('number', to_render)

    def set_status(self, text):
        self.edje_obj.part_text_set('status', text)

    def get_status(self):
        return self.edje_obj.part_text_get('status')

app = ThrowApp()
ecore.main_loop_begin()
